Struct amazon_sp_notifications::models::event_bridge_resource_specification::EventBridgeResourceSpecification
source · [−]Expand description
EventBridgeResourceSpecification : The information required to create an Amazon EventBridge destination.
Fields
region: StringThe AWS region in which you will be receiving the notifications.
account_id: StringThe identifier for the AWS account that is responsible for charges related to receiving notifications.
Implementations
sourceimpl EventBridgeResourceSpecification
impl EventBridgeResourceSpecification
sourcepub fn new(
region: String,
account_id: String
) -> EventBridgeResourceSpecification
pub fn new(
region: String,
account_id: String
) -> EventBridgeResourceSpecification
The information required to create an Amazon EventBridge destination.